%define revision 1

%global provider        github
%global provider_tld    com
%global project         Icinga
%global repo            icingadb
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

%global golang_min_version 1.11

%if "%{_vendor}" == "suse"
%global golang_pkg      go
%else # suse
%global golang_pkg      golang
%endif # suse

%if 0%{?golang_scl:1}
%global golang_scl_prefix %{golang_scl}-
%global golang_scl_enable scl enable %{golang_scl} --
%endif

%if ! 0%{?gobuild:1}
%define gobuild(o:) %{?golang_scl_enable} go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%endif

%if ! 0%{?gopath:1}
%define gopath %(%{?golang_scl_enable} go env GOPATH)
%endif

Name:       icingadb
Version: 0.0.0.535.3e3bb5a6
Release: 0.20200312.1347%{?dist}
Summary:    Icinga DB
Group:      System Environment/Daemons
%if "%{_vendor}" == "suse"
License:    GPL-2.0-or-later
%else
License:    GPLv2+
%endif # suse
URL:        https://%{provider_prefix}
Source0: icingadb-0.0.0.535.3e3bb5a6.tar.gz

Source1:    icingadb-redis.service.suse
Source2:    icingadb-redis.service.rhel
Source3:    icingadb-redis.conf

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}

BuildRequires:  %{?golang_scl_prefix}%{golang_pkg} >= %{golang_min_version}
BuildRequires:  git

%{?systemd_requires}
BuildRequires:  systemd

%define debug_package %nil

Requires:       icinga-redis

%if "%{_vendor}" == "suse"
PreReq:         permissions
Provides:       user(icingadb)
Provides:       group(icingadb)
Requires(pre):  shadow
Requires(post): shadow
%else # suse
Requires(pre):  shadow-utils
%endif # suse

%define configdir %{_sysconfdir}/%{name}
%define service %{name}.service

%description
Icinga DB

%package redis
Summary:	Icinga Redis for Icinga DB
Group:          System/Monitoring
Requires:	icinga-redis

%description redis
Redis service for Icinga DB.

%prep
%setup -q

%build
export GO111MODULE=on

%gobuild .

%check
%if ! 0%{?gotest:1}
%global gotest %{?golang_scl_enable} go test
%endif

#%%gotest ./...

%install
install -d -m 0755 %{buildroot}%{_sbindir}
install -d -m 0755 %{buildroot}%{configdir}
install -d -m 0755 %{buildroot}%{_unitdir}

install -m 0755 icingadb %{buildroot}%{_sbindir}/
install -m 0644 icingadb.ini %{buildroot}%{configdir}/icingadb.ini
install -m 0644 etc/%{service} %{buildroot}%{_unitdir}/

install -d -m 0755 %{buildroot}%{_datadir}/%{name}
(umask 0022 && cp -rv etc/schema %{buildroot}%{_datadir}/%{name}/)

%if "%{_vendor}" == "suse"
ln -sf /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
%endif # suse

#%%install redis

install -d -m 0755 %{buildroot}%{_sharedstatedir}/icinga-redis/icingadb-redis

# Install custom systemd service file for icingadb-redis. Source1 is SUSE, Source2 is RHEL.
%if "%{_vendor}" == "suse"
  install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/icingadb-redis.service
%else
  install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/icingadb-redis.service
%endif

install -D -m 0640 %{SOURCE3} %{buildroot}%{_sysconfdir}/icinga-redis/icingadb-redis.conf

%pre
getent group icingadb >/dev/null || groupadd -r icingadb
getent passwd icingadb >/dev/null || useradd -r -g icingadb -d / -s /sbin/nologin -c 'Icinga DB' icingadb

%if "%{_vendor}" == "suse"
%service_add_pre %{service}
%endif # suse

%pre redis
%if "%{_vendor}" == "suse"
  %service_add_pre icingadb-redis.service
%endif

%post
%if "%{_vendor}" == "suse"
%service_add_post %{service}
%else # suse
%systemd_post %{service}
%endif # suse

%post redis
%if "%{_vendor}" == "suse"
%fillup_only  icingadb-redis
%service_add_post icingadb-redis.service
%else
# rhel
%systemd_post icingadb-redis.service
%endif

%preun
%if "%{_vendor}" == "suse"
%service_del_preun %{service}
%else # suse
%systemd_preun %{service}
%endif # suse

%preun redis
# suse
%if "%{_vendor}" == "suse"
%service_del_preun icingadb-redis.service
%else # rhel
%systemd_preun icingadb-redis.service
%endif # suse / rhel
exit 0

%postun
%if "%{_vendor}" == "suse"
%service_del_postun %{service}
%else # suse
%systemd_postun %{service}
%endif # suse

%postun redis
# suse
%if "%{_vendor}" == "suse"
%service_del_postun icingadb-redis.service
%else # rhel
%systemd_postun_with_restart icingadb-redis.service
%endif # suse / rhel
exit 0

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc LICENSE AUTHORS README.md CHANGELOG.md
%{_sbindir}/icingadb
%{_unitdir}/%{service}

%if "%{_vendor}" == "suse"
%{_sbindir}/rc%{name}
%endif # suse

%dir %{_datadir}/%{name}
%{_datadir}/%{name}/schema

%defattr(0640,icingadb,icingadb,0750)

%dir %{configdir}
%config(noreplace) %{configdir}/icingadb.ini

%files redis
%defattr(-,root,root,-)
#%%doc AUTHORS COPYING README.md
%config(noreplace) %attr(0640,icinga-redis,icinga-redis) %{_sysconfdir}/icinga-redis/icingadb-redis.conf
%attr(644,root,root) %{_unitdir}/icingadb-redis.service
%dir %attr(750,icinga-redis,icinga-redis) %{_sharedstatedir}/icinga-redis/icingadb-redis

%changelog
* Fri Dec 13 2019 Henrik Triem <henrik.triem@icinga.com> 0.0.0-1
* Mon Sep 24 2018 Markus Frosch <markus.frosch@icinga.com> 0.0.0-0
- Initial package
